@@ -30,7 +30,7 @@
 #include <config.h>
 #endif
 
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 #include "gedit-close-confirmation-dialog.h"
 #include <gedit/gedit-utils.h>
@@ -132,15 +132,15 @@ gedit_close_confirmation_dialog_init (GeditCloseConfirmationDialog *dlg)
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dlg)->vbox), 14);
 	gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dlg), FALSE);
-  
+
 	gtk_window_set_title (GTK_WINDOW (dlg), "");
-	
+
 	gtk_window_set_modal (GTK_WINDOW (dlg), TRUE);
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (dlg), TRUE);
 
-	gedit_dialog_add_button (GTK_DIALOG (dlg),
-				_("Do_n't save"), GTK_STOCK_NO,
-				GTK_RESPONSE_NO);
+	gtk_dialog_add_button (GTK_DIALOG (dlg),
+			       _("Close _without Saving"),
+			       GTK_RESPONSE_NO);
 
 	gtk_dialog_add_buttons (GTK_DIALOG (dlg),
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -185,6 +185,9 @@ gedit_close_confirmation_dialog_finalize (GObject *object)
 	if (priv->unsaved_documents != NULL)
 		g_slist_free (priv->unsaved_documents);
 
+	if (priv->unsaved_documents != NULL)
+		g_slist_free (priv->selected_documents);
+
 	/* Call the parent's destructor */
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -312,7 +315,7 @@ gedit_close_confirmation_dialog_get_selected_documents (GeditCloseConfirmationDi
 
 	priv = GEDIT_CLOSE_CONFIRMATION_DIALOG_GET_PRIVATE (dlg);
 
-	return priv->selected_documents;
+	return g_slist_copy (priv->selected_documents);
 }
 
 GtkWidget *
@@ -422,7 +425,7 @@ get_text_secondary_label (GeditDocument *doc)
 		hours = seconds / 3600;
 
 		secondary_msg = g_strdup_printf (
-					ngettext ("If you don't save, changes from the last %d hour "
+					ngettext ("If you don't save, changes from the last hour "
 					    	  "will be permanently lost.",
 						  "If you don't save, changes from the last %d hours "
 					    	  "will be permanently lost.",
@@ -433,7 +436,6 @@ get_text_secondary_label (GeditDocument *doc)
 	return secondary_msg;
 }
 
-/* FIXME: Primary and secondary label should be selectable - Paolo (Jan 11, 2004) */
 static void
 build_single_doc_dialog (GeditCloseConfirmationDialog *dlg)
 {
@@ -464,6 +466,7 @@ build_single_doc_dialog (GeditCloseConfirmationDialog *dlg)
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0.0, 0.5);
+	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
 	doc_name = gedit_document_get_short_name (doc);
 	str = g_strdup_printf (_("Save the changes to document \"%s\" before closing?"),
@@ -482,6 +485,7 @@ build_single_doc_dialog (GeditCloseConfirmationDialog *dlg)
 	g_free (str);
 	gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (secondary_label), 0.0, 0.5);
+	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
 
 	hbox = gtk_hbox_new (FALSE, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
@@ -619,10 +623,7 @@ build_multiple_docs_dialog (GeditCloseConfirmationDialog *dlg)
 	hbox = gtk_hbox_new (FALSE, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
   	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), 
-			    hbox, 
-	                    FALSE, 
-			    FALSE, 
-			    0);
+			    hbox, TRUE, TRUE, 0);
 
 	/* Image */
 	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, 
@@ -631,13 +632,14 @@ build_multiple_docs_dialog (GeditCloseConfirmationDialog *dlg)
 	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 
 	vbox = gtk_vbox_new (FALSE, 12);
-	gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 
 	/* Primary label */
 	primary_label = gtk_label_new (NULL);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0.0, 0.5);
+	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
 	str = g_strdup_printf (
 			ngettext ("There is %d document with unsaved changes. "
@@ -679,6 +681,7 @@ build_multiple_docs_dialog (GeditCloseConfirmationDialog *dlg)
 	gtk_box_pack_start (GTK_BOX (vbox2), secondary_label, FALSE, FALSE, 0);
 	gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (secondary_label), 0, 0.5);
+	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (select_label), treeview);
 
@@ -708,4 +711,3 @@ set_unsaved_document (GeditCloseConfirmationDialog *dlg,
 	}	
 }
 
-
