@@ -46,23 +46,12 @@
 #include <config.h>
 #endif
 
-#include "gedit-file-selector-util.h"
-
 #include <string.h>
-#include <unistd.h>
-#include <errno.h>
-
-#include <bonobo/bonobo-event-source.h>
-#include <bonobo/bonobo-exception.h>
-#include <bonobo/bonobo-widget.h>
-
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
-
-#include <bonobo/bonobo-i18n.h>
-
 #include <libgnomevfs/gnome-vfs.h>
-#include <eel/eel-alert-dialog.h>
 
+#include "gedit-file-selector-util.h"
 #include "gedit-utils.h"
 #include "gedit-encodings-option-menu.h"
 
@@ -88,8 +77,7 @@ replace_dialog (GtkWindow *parent,
 		const gchar *uri,
 		const gchar *secondary_message)
 {
-	GtkWidget *msgbox;
-	AtkObject *obj;
+	GtkWidget *dialog;
 	gint ret;
 	gchar *full_formatted_uri;
        	gchar *uri_for_display	;
@@ -97,7 +85,7 @@ replace_dialog (GtkWindow *parent,
 
 	full_formatted_uri = gnome_vfs_format_uri_for_display (uri);
 	g_return_val_if_fail (full_formatted_uri != NULL, FALSE);
-	
+
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
 	 * white space then the text-wrapping code is too stupid to wrap it.
@@ -109,31 +97,29 @@ replace_dialog (GtkWindow *parent,
 	message_with_uri = g_strdup_printf (primary_message, uri_for_display);
 	g_free (uri_for_display);
 
-	msgbox = eel_alert_dialog_new (parent,
-				       GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-				       GTK_MESSAGE_QUESTION,
-				       GTK_BUTTONS_NONE,
-				       message_with_uri,
-				       secondary_message,
-				       NULL);
+	dialog = gtk_message_dialog_new (parent,
+					 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+					 GTK_MESSAGE_QUESTION,
+					 GTK_BUTTONS_NONE,
+					 "%s", message_with_uri);
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+						  "%s", secondary_message);
+
 	g_free (message_with_uri);
 
-	/* Add Cancel button */
-	gtk_dialog_add_button (GTK_DIALOG (msgbox), 
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), 
+			       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 
-	/* Add Replace button */
-	gedit_dialog_add_button (GTK_DIALOG (msgbox), 
+	gedit_dialog_add_button (GTK_DIALOG (dialog), 
 			_("_Replace"), GTK_STOCK_REFRESH, GTK_RESPONSE_YES);
 
-	gtk_dialog_set_default_response	(GTK_DIALOG (msgbox), GTK_RESPONSE_CANCEL);
+	gtk_dialog_set_default_response	(GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
 
-	obj = gtk_widget_get_accessible (msgbox);
-	if (GTK_IS_ACCESSIBLE (obj))
-		atk_object_set_name (obj, _("Question"));
+	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 
-	ret = gtk_dialog_run (GTK_DIALOG (msgbox));
-	gtk_widget_destroy (msgbox);
+	ret = gtk_dialog_run (GTK_DIALOG (dialog));
+
+	gtk_widget_destroy (dialog);
 
 	return (ret == GTK_RESPONSE_YES);
 }
@@ -194,24 +180,6 @@ is_read_only (const gchar *name)
 	return ret;	
 }
 
-static gboolean 
-file_exists (gchar *name)
-{
-	GnomeVFSURI *uri;
-	gboolean ret;
-	
-	g_return_val_if_fail (name != NULL, FALSE);
-
-	uri = gnome_vfs_uri_new (name);
-	g_return_val_if_fail (uri != NULL, FALSE);
-
-	ret = gnome_vfs_uri_exists (uri);
-
-	gnome_vfs_uri_unref (uri);
-
-	return ret;
-}
-
 static gpointer
 analyze_response (GtkFileChooser *chooser, gint response)
 {
@@ -292,7 +260,7 @@ analyze_response (GtkFileChooser *chooser, gint response)
 	{	
 		if (GET_MODE (chooser) == FILESEL_SAVE)
 		{
-			if (file_exists (uri))
+			if (gedit_utils_uri_exists (uri))
 			{
 				if (is_read_only (uri))
 				{
@@ -344,7 +312,7 @@ create_gtk_selector (GtkWindow *parent,
 		     FileselMode mode,
 		     const char *title,
 		     const char *default_path,
-		     const char *default_filename,
+		     const char *default_uri,
 		     const char *untitled_name,
 		     gboolean use_encoding,
 		     const GeditEncoding *encoding)
@@ -432,27 +400,16 @@ create_gtk_selector (GtkWindow *parent,
 	}
 	else
 	{
-		if (default_filename == NULL)
+		if (default_uri == NULL)
 		{
 			if (default_path != NULL)
-			{
 				gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (filesel), default_path);
-			}
 
 			g_return_val_if_fail (untitled_name != NULL, GTK_WINDOW (filesel));
 			gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (filesel), untitled_name);
 		}
 		else
-		{
-			if (default_path != NULL)
-			{
-				gchar *uri;
-
-				uri = g_strconcat (default_path, "/", default_filename, NULL);
-				gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (filesel), uri);
-				g_free (uri);
-			}
-		}
+			gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (filesel), default_uri);
 	}
 
 	if (mode == FILESEL_OPEN_MULTI) 
@@ -467,7 +424,7 @@ run_file_selector (GtkWindow  *parent,
 		   FileselMode mode, 
 		   const char *title,
 		   const char *default_path, 
-		   const char *default_filename,
+		   const char *default_uri,
 		   const char *untitled_name,
 		   const GeditEncoding **encoding)
 
@@ -480,7 +437,7 @@ run_file_selector (GtkWindow  *parent,
 				      mode,
 				      title,
 				      default_path, 
-				      default_filename, 
+				      default_uri, 
 				      untitled_name,
 				      (encoding != NULL),
 				      (encoding != NULL) ? *encoding : NULL);
@@ -573,12 +530,16 @@ gedit_file_selector_open_multi (GtkWindow  *parent,
  * @enable_vfs: if FALSE, restrict files to local paths.
  * @title: optional window title to use
  * @default_path: optional directory to start in (must be an URI)
- * @default_filename: optional file name to default to
+ * @default_uri: optional URI to default to
  * @untitled_name: optional untitled name (valid UTF-8)
  *
  * Creates and shows a modal save file dialog, waiting for the user to
  * select a file or cancel before returning.
  *
+ * If @default_uri is %NULL, then only @default_path and @untitled_name will be
+ * used.  Otherwise, only the @default_uri will be used; the starting directory
+ * will correspond to the last directory component of that URI.
+ *
  * Return value: the URI of the file selected, or NULL if cancel
  * was pressed.
  **/
@@ -587,14 +548,14 @@ gedit_file_selector_save (GtkWindow  *parent,
 			   gboolean    enable_vfs,
 			   const char *title,
 			   const char *default_path, 
-			   const char *default_filename,
+			   const char *default_uri,
 			   const char *untitled_name,
 			   const GeditEncoding **encoding)
 {
-	g_return_val_if_fail (((default_filename != NULL) && (untitled_name == NULL)) ||
-                              ((default_filename == NULL) && (untitled_name != NULL)), NULL);
+	g_return_val_if_fail (((default_uri != NULL) && (untitled_name == NULL)) ||
+                              ((default_uri == NULL) && (untitled_name != NULL)), NULL);
 
 	return run_file_selector (parent, enable_vfs, FILESEL_SAVE,
 				  title ? title : _("Select a filename to save"),
-				  default_path, default_filename, untitled_name, encoding);
+				  default_path, default_uri, untitled_name, encoding);
 }
